==> tine20-allinone_2019.12.5.tar.bz2: ActiveSync/js/ActiveSync-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fr\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "SyncDevice, SyncDevices"
: [
  ""
 ,""

]
, "Sync Devices"
: ""

, "ID"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "AS Version"
: ""

, "Useragent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendarfilter"
: ""

, "Contactsfilter"
: ""

, "Emailfilter"
: ""

, "Tasksfilter"
: ""

, "Last Ping"
: ""

, "Remote Reset Device"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device is reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Device, Devices"
: [
  "Appareil"
 ,"Appareils"

]
, "Devices"
: "Appareils"

, "Active Sync"
: "ActiveSync"

, "Select a Device"
: "Sélectionnez un appareil"

, "No ActiveSync Device registered"
: "Aucun appareil ActiveSync enregistré"

, "Set as {0} Filter"
: "Définir en tant que filtre {0}"

, "Resetted Sync Filter"
: "Filtre de synchronisations réinitialisé"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "Le filtre {0} pour l'appareil \"{1}\" est désormais \"{2}\""

, "resetted"
: "réinitialisé"

, "Set Sync Filter"
: "Définir le filtre de synchronisation"

, "Default Addressbook"
: "Carnet d'adresses par défaut"

, "The default addressbook to create new contacts in."
: "Carnet d'adresse où seront créés par défaut les nouveaux contacts."

, "Default Calendar"
: "Agenda par défaut"

, "The default calendar to create new events in."
: "Calendrier où seront créés par défaut les nouveaux évènements."

, "Default Task List"
: "Liste des tâches par défaut"

, "The default task list to create new tasks in."
: "Liste où seront créés par défaut les nouvelles tâches."

, "Default policy for new devices"
: "Politique par défaut pour les nouveaux appareils"

, "Enter the id of the policy to apply to newly created devices."
: "Entrez le numéro de la politique qui s'appliquera aux appareils nouvellement enregistrés"

, "Disable Access Log"
: "Désactiver la journalisation des accès"

, "Disable ActiveSync Access Log creation."
: "Désactiver la journalisation des accès"

, "Filter timeslot for emails"
: "Jours à synchroniser pour les messages"

, "For how long in the past the emails should be synchronized."
: "Période de synchronisation des messages passés"

, "Filter timeslot for events"
: "Jours à synchroniser pour les évènements"

, "For how long in the past the events should be synchronized."
: "Période de synchronisation des événements passés"

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Default Policy"
: "Règle par défaut"

, "Default Policy installed during setup"
: "Politique par défaut configurée durant l'installation"

, "SyncDevice"
: ""

, "Device"
: "Appareil"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: ActiveSync/js/ActiveSync-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Agenda par défaut"

, "The default calendar to create new events in."
: "Calendrier où seront créés par défaut les nouveaux évènements."

, "Default Task List"
: "Liste des tâches par défaut"

, "The default task list to create new tasks in."
: "Liste où seront créés par défaut les nouvelles tâches."

, "Sync Devices"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Appareil"
 ,"Appareils"

]
, "Devices"
: "Appareils"

, "Active Sync"
: "ActiveSync"

, "Select a Device"
: "Sélectionnez un appareil"

, "No ActiveSync Device registered"
: "Aucun appareil ActiveSync enregistré"

, "Set as {0} Filter"
: "Définir en tant que filtre {0}"

, "Resetted Sync Filter"
: "Filtre de synchronisations réinitialisé"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "Le filtre {0} pour l'appareil \"{1}\" est désormais \"{2}\""

, "resetted"
: "réinitialisé"

, "Set Sync Filter"
: "Définir le filtre de synchronisation"

, "ID"
: ""

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Default Policy"
: "Règle par défaut"

, "Default Policy installed during setup"
: "Politique par défaut configurée durant l'installation"

, "Default policy for new devices"
: "Politique par défaut pour les nouveaux appareils"

, "Enter the id of the policy to apply to newly created devices."
: "Entrez le numéro de la politique qui s'appliquera aux appareils nouvellement enregistrés"

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Désactiver la journalisation des accès"

, "Disable ActiveSync Access Log creation."
: "Désactiver la journalisation des accès"

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Jours à synchroniser pour les évènements"

, "For how long in the past the events should be synchronized."
: "Période de synchronisation des événements passés"

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""





, "Sync Device"
: ""

, "Device"
: "Appareil"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
